@@ -5,7 +5,7 @@ cshp <- function(date=NA, useGW=TRUE) {
     	stop("date is not of type Date")
   	}
   
-  	if (!is.na(date) && (date < as.Date("1946-1-1") | date > as.Date("2008-6-30"))) {
+  	if (!is.na(date) && (date < as.Date("1946-1-1") | date > as.Date("2012-6-30"))) {
     	stop("Specified date is out of range")
   	}
 	
@@ -21,13 +21,13 @@ cshp <- function(date=NA, useGW=TRUE) {
 	  	cshp.full <- cshp.full[cshp.full$GWCODE>=0,]
 		startdate <- as.Date(paste(cshp.full$GWSYEAR, cshp.full$GWSMONTH, cshp.full$GWSDAY, sep="-"))
 		enddate <- as.Date(paste(cshp.full$GWEYEAR, cshp.full$GWEMONTH, cshp.full$GWEDAY, sep="-"))
-		cshp.part <- cshp.full[startdate < date & enddate >= date,]
+		cshp.part <- cshp.full[startdate <= date & enddate >= date,]
 		cshp.part
 	} else {
 		cshp.full <- cshp.full[cshp.full$COWCODE>=0,]
 		startdate <- as.Date(paste(cshp.full$COWSYEAR, cshp.full$COWSMONTH, cshp.full$COWSDAY, sep="-"))
 		enddate <- as.Date(paste(cshp.full$COWEYEAR, cshp.full$COWEMONTH, cshp.full$COWEDAY, sep="-"))
-		cshp.part <- cshp.full[startdate < date & enddate >= date,]
+		cshp.part <- cshp.full[startdate <= date & enddate >= date,]
 		cshp.part
 	}	
 
